@@ -35,9 +35,9 @@ std::string RunTrainer(
     const std::vector<std::string> &input, int size,
     const std::vector<std::string> &user_defined_symbols = {}) {
   const std::string input_file =
-      util::JoinPath(absl::GetFlag(FLAGS_test_tmpdir), "input");
+      util::JoinPath(::testing::TempDir(), "input");
   const std::string model_prefix =
-      util::JoinPath(absl::GetFlag(FLAGS_test_tmpdir), "model");
+      util::JoinPath(::testing::TempDir(), "model");
   {
     auto output = filesystem::NewWritableFile(input_file);
     for (const auto &line : input) {
@@ -93,13 +93,13 @@ static constexpr char kTestInputData[] = "wagahaiwa_nekodearu.txt";
 
 TEST(BPETrainerTest, EndToEndTest) {
   const std::string input =
-      util::JoinPath(absl::GetFlag(FLAGS_test_srcdir), kTestInputData);
+      util::JoinPath(::testing::SrcDir(), kTestInputData);
 
   ASSERT_TRUE(
       SentencePieceTrainer::Train(
           absl::StrCat(
               "--model_prefix=",
-              util::JoinPath(absl::GetFlag(FLAGS_test_tmpdir), "tmp_model"),
+              util::JoinPath(::testing::TempDir(), "tmp_model"),
               " --input=", input,
               " --vocab_size=8000 --normalization_rule_name=identity"
               " --model_type=bpe --control_symbols=<ctrl> "
@@ -108,7 +108,7 @@ TEST(BPETrainerTest, EndToEndTest) {
 
   SentencePieceProcessor sp;
   ASSERT_TRUE(sp.Load(std::string(util::JoinPath(
-                          absl::GetFlag(FLAGS_test_tmpdir), "tmp_model.model")))
+                          ::testing::TempDir(), "tmp_model.model")))
                   .ok());
   EXPECT_EQ(8000, sp.GetPieceSize());
 
