@@ -98,6 +98,8 @@ class Builder {
   // Merge Unicode case folding mapping into `chars_map`.
   static util::Status MergeUnicodeCaseFoldMap(CharsMap *chars_map);
 
+  static util::Status MergeNmtMap(Builder::CharsMap *chars_map);
+
   // Makes NFKC with Unicode case folding.
   static util::Status BuildNFKC_CFMap(CharsMap *chars_map);
 
@@ -107,6 +109,21 @@ class Builder {
   // Given NFKC maps, convert them to NFKD.
   static util::Status BuildNFKDMap(CharsMap *chars_map);
 
+  // Builds NFC map.
+  static util::Status BuildNFCMap(CharsMap *chars_map);
+
+  // Builds NFD map.
+  static util::Status BuildNFDMap(CharsMap *chars_map);
+
+  // Makes NFKD with Unicode case folding.
+  static util::Status BuildNFKD_CFMap(CharsMap *chars_map);
+
+  // Makes NFKC with Unicode case folding.
+  static util::Status BuildNFC_CFMap(CharsMap *chars_map);
+
+  // Makes NFD with Unicode case folding.
+  static util::Status BuildNFD_CFMap(CharsMap *chars_map);
+
   // Builds Chars map save in `filename`.
   // Format:
   // src_uchar1 src_uchar2 ... <tab> trg_uchar1 trg_uchar2...
@@ -118,13 +135,13 @@ class Builder {
   static util::Status SaveCharsMap(absl::string_view filename,
                                    const CharsMap &chars_map);
 
- private:
-  FRIEND_TEST(BuilderTest, RemoveRedundantMapTest);
-
   // Removes redundant rules from `chars_map`.
   // When char_maps have "aa" => "bb" and "a" => "b", the first
   // rule is not necessary since the second rule can cover the first rule.
   static util::Status RemoveRedundantMap(CharsMap *chars_map);
+
+ private:
+  FRIEND_TEST(BuilderTest, RemoveRedundantMapTest);
 };
 }  // namespace normalizer
 }  // namespace sentencepiece
