@@ -13,6 +13,7 @@
 // limitations under the License.!
 
 #include "builder.h"
+
 #include "common.h"
 #include "filesystem.h"
 #include "normalizer.h"
@@ -61,6 +62,8 @@ TEST(BuilderTest, BuildNFKCMapTest) {
 }
 
 TEST(BuilderTest, GetPrecompiledCharsMapTest) {
+  SetDataDir(::testing::SrcDir());
+
   {
     const NormalizerSpec spec =
         SentencePieceTrainer::GetNormalizerSpec("nmt_nfkc");
@@ -142,9 +145,8 @@ static constexpr char kTestInputData[] = "nfkc.tsv";
 TEST(BuilderTest, LoadCharsMapTest) {
   Builder::CharsMap chars_map;
   ASSERT_TRUE(
-      Builder::LoadCharsMap(
-          util::JoinPath(absl::GetFlag(FLAGS_test_srcdir), kTestInputData),
-          &chars_map)
+      Builder::LoadCharsMap(util::JoinPath(::testing::SrcDir(), kTestInputData),
+                            &chars_map)
           .ok());
 
   std::string precompiled, expected;
@@ -156,17 +158,14 @@ TEST(BuilderTest, LoadCharsMapTest) {
       Builder::DecompileCharsMap(precompiled, &decompiled_chars_map).ok());
   EXPECT_EQ(chars_map, decompiled_chars_map);
 
-  ASSERT_TRUE(
-      Builder::SaveCharsMap(
-          util::JoinPath(absl::GetFlag(FLAGS_test_tmpdir), "output.tsv"),
-          chars_map)
-          .ok());
+  ASSERT_TRUE(Builder::SaveCharsMap(
+                  util::JoinPath(::testing::TempDir(), "output.tsv"), chars_map)
+                  .ok());
 
   Builder::CharsMap saved_chars_map;
   ASSERT_TRUE(
-      Builder::LoadCharsMap(
-          util::JoinPath(absl::GetFlag(FLAGS_test_tmpdir), "output.tsv"),
-          &saved_chars_map)
+      Builder::LoadCharsMap(util::JoinPath(::testing::TempDir(), "output.tsv"),
+                            &saved_chars_map)
           .ok());
   EXPECT_EQ(chars_map, saved_chars_map);
 
@@ -180,7 +179,7 @@ TEST(BuilderTest, LoadCharsMapTest) {
 TEST(BuilderTest, LoadCharsMapWithEmptyeTest) {
   {
     auto output = filesystem::NewWritableFile(
-        util::JoinPath(absl::GetFlag(FLAGS_test_tmpdir), "test.tsv"));
+        util::JoinPath(::testing::TempDir(), "test.tsv"));
     output->WriteLine("0061\t0041");
     output->WriteLine("0062");
     output->WriteLine("0063\t\t#foo=>bar");
@@ -188,8 +187,7 @@ TEST(BuilderTest, LoadCharsMapWithEmptyeTest) {
 
   Builder::CharsMap chars_map;
   EXPECT_TRUE(Builder::LoadCharsMap(
-                  util::JoinPath(absl::GetFlag(FLAGS_test_tmpdir), "test.tsv"),
-                  &chars_map)
+                  util::JoinPath(::testing::TempDir(), "test.tsv"), &chars_map)
                   .ok());
 
   EXPECT_EQ(3, chars_map.size());
@@ -199,15 +197,13 @@ TEST(BuilderTest, LoadCharsMapWithEmptyeTest) {
 
   EXPECT_TRUE(
       Builder::SaveCharsMap(
-          util::JoinPath(absl::GetFlag(FLAGS_test_tmpdir), "test_out.tsv"),
-          chars_map)
+          util::JoinPath(::testing::TempDir(), "test_out.tsv"), chars_map)
           .ok());
 
   Builder::CharsMap new_chars_map;
   EXPECT_TRUE(
       Builder::LoadCharsMap(
-          util::JoinPath(absl::GetFlag(FLAGS_test_tmpdir), "test_out.tsv"),
-          &new_chars_map)
+          util::JoinPath(::testing::TempDir(), "test_out.tsv"), &new_chars_map)
           .ok());
   EXPECT_EQ(chars_map, new_chars_map);
 }
