@@ -32,7 +32,7 @@ util::Status Trainer::Train() {
   const int vocab_size = trainer_spec_.vocab_size() - meta_pieces_.size();
   CHECK_GE_OR_RETURN(vocab_size, 0);
 
-  uint64 sum = 0;
+  uint64_t sum = 0;
   for (const auto &it : required_chars_) {
     sum += it.second;
   }
