@@ -23,7 +23,7 @@
 // We want to define them in other cc file.
 #include "third_party/absl/flags/flag.h"
 #include "third_party/absl/flags/parse.h"
-ABSL_FLAG(int32, minloglevel, 0,
+ABSL_FLAG(int32_t, minloglevel, 0,
           "Messages logged at a lower level than this don't actually.");
 #endif
 
