@@ -12,11 +12,11 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.!
 
+#include "model_interface.h"
+
 #include <algorithm>
 
-#include "model_interface.h"
 #include "sentencepiece_model.pb.h"
-#include "third_party/absl/memory/memory.h"
 #include "third_party/absl/strings/str_format.h"
 #include "util.h"
 
@@ -68,6 +68,23 @@ void ModelInterface::InitializePieces() {
   std::set<absl::string_view> user_defined_symbols;
   std::vector<bool> byte_found(256, false);
 
+  int pieces_size = 0;
+  int reserved_id_map_size = 0;
+  for (int i = 0; i < model_proto_->pieces_size(); ++i) {
+    const auto &sp = model_proto_->pieces(i);
+    const bool is_normal_piece =
+        (sp.type() == ModelProto::SentencePiece::NORMAL ||
+         sp.type() == ModelProto::SentencePiece::USER_DEFINED ||
+         sp.type() == ModelProto::SentencePiece::UNUSED);
+    if (is_normal_piece) {
+      ++pieces_size;
+    } else {
+      ++reserved_id_map_size;
+    }
+  }
+  pieces_.reserve(pieces_size);
+  reserved_id_map_.reserve(reserved_id_map_size);
+
   for (int i = 0; i < model_proto_->pieces_size(); ++i) {
     const auto &sp = model_proto_->pieces(i);
     if (sp.piece().empty()) {
@@ -130,36 +147,57 @@ void ModelInterface::InitializePieces() {
     }
   }
 
-  matcher_ = absl::make_unique<normalizer::PrefixMatcher>(user_defined_symbols);
+  matcher_ = std::make_unique<normalizer::PrefixMatcher>(user_defined_symbols);
 }
 
 std::vector<absl::string_view> SplitIntoWords(absl::string_view text,
-                                              bool treat_whitespace_as_suffix) {
+                                              bool treat_ws_as_suffix,
+                                              bool allow_ws_only_pieces) {
   const char *begin = text.data();
   const char *end = text.data() + text.size();
 
   // Space symbol (U+2581)
   const absl::string_view kSpaceSymbol = "\xe2\x96\x81";
+  bool in_ws_sequence = false;
 
   std::vector<absl::string_view> result;
-  if (treat_whitespace_as_suffix) {
+  if (treat_ws_as_suffix) {  // put ws tokens at the end of non-ws sequences.
     if (begin < end) result.emplace_back(begin, 0);
     while (begin < end) {
       const int mblen =
           std::min<int>(string_util::OneCharLen(begin), end - begin);
       const bool is_ws = absl::string_view(begin, mblen) == kSpaceSymbol;
+
+      if (is_ws) {  // keep track of sequences consecutive ws tokens.
+        in_ws_sequence = true;
+      } else if (in_ws_sequence) {
+        if (allow_ws_only_pieces) result.emplace_back(begin, 0);
+
+        in_ws_sequence = false;
+      }
+
       result.back() =
           absl::string_view(result.back().data(), result.back().size() + mblen);
       begin += mblen;
-      if (begin < end && is_ws) result.emplace_back(begin, 0);
+
+      if (begin < end && is_ws && !allow_ws_only_pieces)
+        result.emplace_back(begin, 0);
     }
   } else {
     while (begin < end) {
       const int mblen =
           std::min<int>(string_util::OneCharLen(begin), end - begin);
+      bool is_ws = absl::string_view(begin, mblen) == kSpaceSymbol;
+
+      // if is whitespace (and not in sequence if allow_ws_only_pieces is True)
       if (begin == text.data() ||
-          absl::string_view(begin, mblen) == kSpaceSymbol)
+          (is_ws && (!in_ws_sequence || !allow_ws_only_pieces))) {
         result.emplace_back(begin, 0);  // add empty string piece.
+        in_ws_sequence = true;
+      }
+
+      if (in_ws_sequence && !is_ws) in_ws_sequence = false;
+
       result.back() =
           absl::string_view(result.back().data(), result.back().size() + mblen);
       begin += mblen;
