@@ -50,10 +50,8 @@ void CheckNormalizer(absl::string_view filename, bool expected_has_normalizer,
 }
 
 TEST(SentencePieceTrainerTest, TrainFromArgsTest) {
-  const std::string input =
-      util::JoinPath(absl::GetFlag(FLAGS_test_srcdir), kTestData);
-  const std::string model =
-      util::JoinPath(absl::GetFlag(FLAGS_test_tmpdir), "m");
+  const std::string input = util::JoinPath(::testing::SrcDir(), kTestData);
+  const std::string model = util::JoinPath(::testing::TempDir(), "m");
 
   ASSERT_TRUE(SentencePieceTrainer::Train(
                   absl::StrCat("--input=", input, " --model_prefix=", model,
@@ -117,10 +115,8 @@ TEST(SentencePieceTrainerTest, TrainFromIterator) {
     size_t idx_ = 0;
   };
 
-  const std::string input =
-      util::JoinPath(absl::GetFlag(FLAGS_test_srcdir), kTestData);
-  const std::string model =
-      util::JoinPath(absl::GetFlag(FLAGS_test_tmpdir), "m");
+  const std::string input = util::JoinPath(::testing::SrcDir(), kTestData);
+  const std::string model = util::JoinPath(::testing::TempDir(), "m");
 
   std::vector<std::string> sentences;
   {
@@ -153,12 +149,9 @@ TEST(SentencePieceTrainerTest, TrainFromIterator) {
 }
 
 TEST(SentencePieceTrainerTest, TrainWithCustomNormalizationRule) {
-  std::string input =
-      util::JoinPath(absl::GetFlag(FLAGS_test_srcdir), kTestData);
-  std::string rule =
-      util::JoinPath(absl::GetFlag(FLAGS_test_srcdir), kNfkcTestData);
-  const std::string model =
-      util::JoinPath(absl::GetFlag(FLAGS_test_tmpdir), "m");
+  std::string input = util::JoinPath(::testing::SrcDir(), kTestData);
+  std::string rule = util::JoinPath(::testing::SrcDir(), kNfkcTestData);
+  const std::string model = util::JoinPath(::testing::TempDir(), "m");
 
   EXPECT_TRUE(SentencePieceTrainer::Train(
                   absl::StrCat("--input=", input, " --model_prefix=", model,
@@ -170,13 +163,12 @@ TEST(SentencePieceTrainerTest, TrainWithCustomNormalizationRule) {
 
 TEST(SentencePieceTrainerTest, TrainWithCustomDenormalizationRule) {
   const std::string input_file =
-      util::JoinPath(absl::GetFlag(FLAGS_test_srcdir), kTestDataJa);
-  const std::string model =
-      util::JoinPath(absl::GetFlag(FLAGS_test_tmpdir), "m");
+      util::JoinPath(::testing::SrcDir(), kTestDataJa);
+  const std::string model = util::JoinPath(::testing::TempDir(), "m");
   const std::string norm_rule_tsv =
-      util::JoinPath(absl::GetFlag(FLAGS_test_srcdir), kIdsNormTsv);
+      util::JoinPath(::testing::SrcDir(), kIdsNormTsv);
   const std::string denorm_rule_tsv =
-      util::JoinPath(absl::GetFlag(FLAGS_test_srcdir), kIdsDenormTsv);
+      util::JoinPath(::testing::SrcDir(), kIdsDenormTsv);
   EXPECT_TRUE(
       SentencePieceTrainer::Train(
           absl::StrCat("--input=", input_file, " --model_prefix=", model,
@@ -198,10 +190,8 @@ TEST(SentencePieceTrainerTest, TrainErrorTest) {
 
 TEST(SentencePieceTrainerTest, TrainTest) {
   TrainerSpec trainer_spec;
-  trainer_spec.add_input(
-      util::JoinPath(absl::GetFlag(FLAGS_test_srcdir), kTestData));
-  trainer_spec.set_model_prefix(
-      util::JoinPath(absl::GetFlag(FLAGS_test_tmpdir), "m"));
+  trainer_spec.add_input(util::JoinPath(::testing::SrcDir(), kTestData));
+  trainer_spec.set_model_prefix(util::JoinPath(::testing::TempDir(), "m"));
   trainer_spec.set_vocab_size(1000);
   NormalizerSpec normalizer_spec;
   ASSERT_TRUE(SentencePieceTrainer::Train(trainer_spec, normalizer_spec).ok());
@@ -365,13 +355,11 @@ TEST(SentencePieceTrainerTest, PopulateModelTypeFromStringTest) {
 }
 
 TEST(SentencePieceTrainerTest, NormalizationTest) {
-  const auto model_prefix =
-      util::JoinPath(absl::GetFlag(FLAGS_test_tmpdir), "m");
+  const auto model_prefix = util::JoinPath(::testing::TempDir(), "m");
   const auto model_file = absl::StrCat(model_prefix, ".model");
 
   TrainerSpec trainer_spec;
-  trainer_spec.add_input(
-      util::JoinPath(absl::GetFlag(FLAGS_test_srcdir), kTestData));
+  trainer_spec.add_input(util::JoinPath(::testing::SrcDir(), kTestData));
   trainer_spec.set_model_prefix(model_prefix);
   trainer_spec.set_vocab_size(1000);
   ASSERT_TRUE(SentencePieceTrainer::Train(trainer_spec).ok());
@@ -423,8 +411,8 @@ TEST(SentencePieceTrainerTest, NormalizationTest) {
 
   {
     SentencePieceNormalizer sp;
-    EXPECT_OK(sp.LoadFromRuleTSV(
-        util::JoinPath(absl::GetFlag(FLAGS_test_srcdir), "nfkc_cf.tsv")));
+    EXPECT_OK(
+        sp.LoadFromRuleTSV(util::JoinPath(::testing::SrcDir(), "nfkc_cf.tsv")));
     set_normalization_only(&sp);
     EXPECT_EQ(sp.Normalize("ABCD"), "abcd");
   }
