@@ -493,7 +493,7 @@ TEST(TrainerInterfaceTest, SerializeTest) {
 
 TEST(TrainerInterfaceTest, CharactersTest) {
   const std::string input_file =
-      util::JoinPath(absl::GetFlag(FLAGS_test_tmpdir), "input");
+      util::JoinPath(::testing::TempDir(), "input");
   {
     auto output = filesystem::NewWritableFile(input_file);
     // Make a single line with 50 "a", 49 "あ", and 1 "b".
@@ -517,7 +517,7 @@ TEST(TrainerInterfaceTest, CharactersTest) {
   trainer_spec.set_model_prefix("model");
   trainer_spec.set_character_coverage(0.98);
 
-  using E = absl::flat_hash_map<char32, int64>;
+  using E = absl::flat_hash_map<char32, int64_t>;
   {
     TrainerInterface trainer(trainer_spec, normalizer_spec, denormalizer_spec);
     EXPECT_OK(trainer.LoadSentences());
@@ -559,7 +559,7 @@ TEST(TrainerInterfaceTest, MultiFileSentenceIteratorTest) {
   std::vector<std::string> files;
   std::vector<std::string> expected;
   for (int i = 0; i < 10; ++i) {
-    const std::string file = util::JoinPath(absl::GetFlag(FLAGS_test_tmpdir),
+    const std::string file = util::JoinPath(::testing::TempDir(),
                                             absl::StrCat("input", i));
     auto output = filesystem::NewWritableFile(file);
     int num_line = (rand() % 100) + 1;
@@ -581,7 +581,7 @@ TEST(TrainerInterfaceTest, MultiFileSentenceIteratorTest) {
 TEST(TrainerInterfaceTest, MultiFileSentenceIteratorErrorTest) {
   std::vector<std::string> files;
   for (int i = 0; i < 10; ++i) {
-    const std::string file = util::JoinPath(absl::GetFlag(FLAGS_test_tmpdir),
+    const std::string file = util::JoinPath(::testing::TempDir(),
                                             absl::StrCat("input_not_exist", i));
     files.push_back(file);
   }
