@@ -12,8 +12,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.!
 
-#include "unicode_script.h"
 #include <unordered_map>
+
+#include "third_party/absl/container/flat_hash_map.h"
+#include "unicode_script.h"
 #include "unicode_script_map.h"
 #include "util.h"
 
@@ -29,7 +31,7 @@ class GetScriptInternal {
   }
 
  private:
-  std::unordered_map<char32, ScriptType> smap_;
+  absl::flat_hash_map<char32, ScriptType> smap_;
 };
 }  // namespace
 
